marktools.Annotation
====================

.. inheritance-diagram:: abjad.tools.marktools.Annotation.Annotation.Annotation
   :private-bases:

.. autoclass:: abjad.tools.marktools.Annotation.Annotation.Annotation

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.name

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.value

Methods
-------

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__eq__

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__str__

   .. note:: Inherited from `__builtin__.object`
